@@ -32,7 +32,7 @@ class UvicornWorker(Worker):
             "app": None,
             "log_config": None,
             "timeout_keep_alive": self.cfg.keepalive,
-            "timeout_notify": self.cfg.timeout,
+            "timeout_notify": self.timeout,
             "callback_notify": self.callback_notify,
             "limit_max_requests": self.max_requests,
             "forwarded_allow_ips": self.cfg.forwarded_allow_ips,
@@ -42,6 +42,7 @@ class UvicornWorker(Worker):
             ssl_kwargs = {
                 "ssl_keyfile": self.cfg.ssl_options.get("keyfile"),
                 "ssl_certfile": self.cfg.ssl_options.get("certfile"),
+                "ssl_keyfile_password": self.cfg.ssl_options.get("password"),
                 "ssl_version": self.cfg.ssl_options.get("ssl_version"),
                 "ssl_cert_reqs": self.cfg.ssl_options.get("cert_reqs"),
                 "ssl_ca_certs": self.cfg.ssl_options.get("ca_certs"),
